BluetoothStream

Enum BluetoothStream 

pub enum BluetoothStream {
    Bluez(Pin<Box<Stream>>),
}
An active stream for bluetooth communications

Variants



Bluez(Pin<Box<Stream>>)

On linux, a stream using the bluez library

Implementations

Source

impl BluetoothStream

pub fn supports_async_read(self: Pin<&mut Self>) -> Option<&mut dyn AsyncRead>

Used to check to see if the object supports async read, and then use the functionality

pub fn supports_async_write(self: Pin<&mut Self>) -> Option<&mut dyn AsyncWrite>

Used to check to see if the object supports async write, and then use the functionality

pub fn supports_sync_read(self: Pin<&mut Self>) -> Option<&mut dyn Read>

Used to try to use synchronous read functionality

pub fn supports_sync_write(self: Pin<&mut Self>) -> Option<&mut dyn Write>

Used to try to use synchronous write functionality