pub enum BluetoothStream {
Bluez(Pin<Box<Stream>>),
}Expand description
An active stream for bluetooth communications
Variants
Implementations
Sourceimpl BluetoothStream
impl BluetoothStream
Sourcepub fn supports_async_read(self: Pin<&mut Self>) -> Option<&mut dyn AsyncRead>
pub fn supports_async_read(self: Pin<&mut Self>) -> Option<&mut dyn AsyncRead>
Used to check to see if the object supports async read, and then use the functionality
Sourcepub fn supports_async_write(self: Pin<&mut Self>) -> Option<&mut dyn AsyncWrite>
pub fn supports_async_write(self: Pin<&mut Self>) -> Option<&mut dyn AsyncWrite>
Used to check to see if the object supports async write, and then use the functionality
Sourcepub fn supports_sync_read(self: Pin<&mut Self>) -> Option<&mut dyn Read>
pub fn supports_sync_read(self: Pin<&mut Self>) -> Option<&mut dyn Read>
Used to try to use synchronous read functionality
Sourcepub fn supports_sync_write(self: Pin<&mut Self>) -> Option<&mut dyn Write>
pub fn supports_sync_write(self: Pin<&mut Self>) -> Option<&mut dyn Write>
Used to try to use synchronous write functionality